% 接合部の釣合モーメント：式(6)（楠原・塩原理論2010：鉄筋コンクリート造十字形柱梁接合部の終局モーメント算定法より）
function [Mjb,Tbb,Tcb,Th,Tm,xi1] = Mjb6_func2(n,flg,Ab,Ac,bb,bc,beta1,beta3,Db,Dc, ...
    eps_u,Esb,Esc,fc,gb,gc,H,L,Nb,Nc,R,Tby,Tcy,Thy,Tmy,Vb,Vc)
% 条件式で T_zyoken(i) = -eps_u/eps_y(i)*Ty(i) を使う場合は，eps_byとeps_cyを関数の中に入れる

% 変数の配列サイズと初期値の決定
iter = ones(n,1);
err_b = ones(n,1);
err_c = ones(n,1);

Tb2 = zeros(n,1);
Tb2max = zeros(n,1);
Tb_zyoken = zeros(n,1);
Tbb = zeros(n,1);
Tc2 = zeros(n,1);
Tc2max = zeros(n,1);
Tc_zyoken = zeros(n,1);
Tcb = zeros(n,1);

Tb2_index = zeros(n,1);
Tc2_index = zeros(n,1);

xi1 = ones(n,1);   % 初期値0→1に変更
xi2x = ones(n,1);  % 初期値0→1に変更
xi2y = ones(n,1);  % 初期値0→1に変更
a = zeros(n,1);
b = zeros(n,1);
c = zeros(n,1);

C1x = zeros(n,1);  % 接合部中央のコンクリート応力の水平成分[N]
C1y = zeros(n,1);  % 接合部中央のコンクリート応力の鉛直成分[N]
C2x = zeros(n,1);  % 接合部入隅部のコンクリート応力の水平成分[N]
C2y = zeros(n,1);  % 接合部入隅部のコンクリート応力の鉛直成分[N]
j1x = zeros(n,1);  % 柱，梁の上段筋から接合部中央のコンクリート応力の作用位置までの距離[mm]
j1y = zeros(n,1);  % 柱，梁の上段筋から接合部中央のコンクリート応力の作用位置までの距離[mm]
j2x = zeros(n,1);  % 柱，梁の下段筋から接合部入隅部のコンクリート応力の作用位置までの距離[mm]
j2y = zeros(n,1);  % 柱，梁の下段筋から接合部入隅部のコンクリート応力の作用位置までの距離[mm]

Mjb = zeros(n,1);   % 接合部の抵抗モーメント[N・mm]
dMj1 = zeros(n,1);  % 接合部の抵抗モーメントの軸力による増分[N・mm]
dMj2 = zeros(n,1);  % 接合部の抵抗モーメントのせん断力による増分[N・mm]
Vb2 = zeros(n,1);
Vc2 = zeros(n,1);

Th = Thy;
Tm = Tmy;

% 接合部の釣合モーメント
for i = 1:n
    err_b(i) = 1;
    err_c(i) = 1;
    while err_b(i) >= 1e-8 && err_c(i) >= 1e-8 && iter(i) <= 100
        % 終局時の鉄筋の応力：梁
        Tb2max(i) = 1/2*(1-gb(i))*bb(i)*Db(i)*beta3*fc(i)-(Nb(i)+Th(i))/2-Vc(i)/2;  % 式(7a)
        Tb_zyoken(i) = -Esb(i)*eps_u*Ab(i);  % 式(8a)
        % Tb_zyoken(i) = -eps_u/eps_by(i)*Tby(i);  % 式(8a)
        if abs(Tb2max(i)) <= abs(Tby(i))
            if Tb2max(i) >= Tb_zyoken(i)
                Tb2(i) = Tb2max(i);
                Tb2_index(i) = 1;
            else
                Tb2(i) = Tb_zyoken(i);
                Tb2_index(i) = 4;
            end
        else
            if Tb2max(i) > Tby(i)
                Tb2(i) = Tby(i);
                Tb2_index(i) = 2;
            else
                if Tby(i) <= -Tb_zyoken(i)
                    Tb2(i) = -Tby(i);
                    Tb2_index(i) = 3;
                else
                    Tb2(i) = Tb_zyoken(i);
                    Tb2_index(i) = 4;
                end
            end
        end
        
        % 終局時の鉄筋の応力：柱
        Tc2max(i) = 1/2*(1-gc(i))*bb(i)*Dc(i)*beta3*fc(i)-(Nc(i)+Tm(i))/2-Vb(i)/2;  % 式(7b)
        Tc_zyoken(i) = -Esc(i)*eps_u*Ac(i);  % 式(8b)
        % Tc_zyoken(i) = -eps_u/eps_cy(i)*Tcy(i);  % 式(8b)
        if abs(Tc2max(i)) <= abs(Tcy(i))
            if Tc2max(i) >= Tc_zyoken(i)
                Tc2(i) = Tc2max(i);
                Tc2_index(i) = 1;
            else
                Tc2(i) = Tc_zyoken(i);
                Tc2_index(i) = 4;
            end
        else
            if Tc2max(i) > Tcy(i)
                Tc2(i) = Tcy(i);
                Tc2_index(i) = 2;
            else
                if Tcy(i) <= -Tc_zyoken(i)
                    Tc2(i) = -Tcy(i);
                    Tc2_index(i) = 3;
                else
                    Tc2(i) = Tc_zyoken(i);
                    Tc2_index(i) = 4;
                end
            end
        end
        
        % 釣り合い破壊時の鉄筋の応力と中立軸位置
        xi2x(i) = 1/beta1(i)*(Tb2(i)+(Nb(i)+Th(i))/2+Vc(i)/2)/(bb(i)*Db(i)*beta3*fc(i));  % 式(20a)
        xi2y(i) = 1/beta1(i)*(Tc2(i)+(Nc(i)+Tm(i))/2+Vb(i)/2)/(bb(i)*Dc(i)*beta3*fc(i));  % 式(20b)
        
        a(i) = 1/(2*(1+R(i)^2)^2*Esb(i)*Ab(i))*gb(i)*bc(i)*Db(i)*beta1(i)*beta3*fc(i) ...
            +1/(2*(1+1/R(i)^2)^2*Esc(i)*Ac(i))*gc(i)*bc(i)*Dc(i)*beta1(i)*beta3*fc(i);
        b(i) = 1/(2*(1+R(i)^2)*Esb(i)*Ab(i))*gb(i)*(-(Nb(i)+Th(i))/2+Vc(i)/2+Tb2(i)) ...
            +1/(2*(1+1/R(i)^2)*Esc(i)*Ac(i))*gc(i)*(-(Nc(i)+Tm(i))/2+Vb(i)/2+Tc2(i))+eps_u;
        c(i) = eps_u*(xi2x(i)+xi2y(i)-1);  % 式(21)及び，岡野先生誘導メモ：付録2
        
        xi1(i) = (-b(i)+sqrt(b(i)^2-4*a(i)*c(i)))/(2*a(i));  % 2次方程式の解の公式
        if flg == 1
            [Th,Tm] = Tpanel(n,Ab,Ac,Db,Dc,eps_u,Esb,Esc,gc,R,Thy,Tmy,xi1,xi2x,xi2y);
        end
        
        % コンクリート応力の大きさ
        C1x(i) = 1/(1+R(i)^2)*xi1(i)*bc(i)*Db(i)*beta1(i)*beta3*fc(i);    % 式(19a)
        C1y(i) = 1/(1+1/R(i)^2)*xi1(i)*bc(i)*Dc(i)*beta1(i)*beta3*fc(i);  % 式(19b)
        C2x(i) = Tb2(i)+(Nb(i)+Th(i))/2+Vc(i)/2;  % 式(1c)
        C2y(i) = Tc2(i)+(Nc(i)+Tm(i))/2+Vb(i)/2;  % 式(1d)
        
        % 接合部の限界補強量
        Tbb(i) = C1x(i)-(Nb(i)+Th(i))/2+Vc(i)/2;  % 式(1a)：この式に，式(19a)を代入すると，式(22a)になる
        Tcb(i) = C1y(i)-(Nc(i)+Tm(i))/2+Vb(i)/2;  % 式(1b)：この式に，式(19b)を代入すると，式(22b)になる
        
        % コンクリート応力の作用位置
        j1x(i) = gb(i)*Db(i)/2-1/2*C1x(i)/(bc(i)*beta3*fc(i));      % 式(2a)
        j1y(i) = gc(i)*Dc(i)/2-1/2*C1y(i)/(bc(i)*beta3*fc(i));      % 式(2b)
        j2x(i) = (1-gb(i))*Db(i)/2-1/2*C2x(i)/(bb(i)*beta3*fc(i));  % 式(2c)
        j2y(i) = (1-gc(i))*Dc(i)/2-1/2*C2y(i)/(bb(i)*beta3*fc(i));  % 式(2d)
        
        % 接合部の抵抗モーメント
        Mjb(i) = Tbb(i)*j1x(i)+Tb2(i)*j2x(i)+Tcb(i)*j1y(i)+Tc2(i)*j2y(i);                                   % 式(3)
        dMj1(i) = (Nb(i)+Th(i))/2*(j1x(i)+j2x(i))+(Nc(i)+Tm(i))/2*(j1y(i)+j2y(i));                          % 式(4)
        dMj2(i) = Vc(i)/2*gb(i)*Db(i)+Vb(i)/2*gc(i)*Dc(i)-Vc(i)/2*(j1x(i)-j2x(i))-Vb(i)/2*(j1y(i)-j2y(i));  % 式(5)
        Mjb(i) = Mjb(i)+dMj1(i)+dMj2(i);                                                                    % 式(6)
        
        % 柱，梁せん断力と接合部の抵抗モーメントの関係
        Vb2(i) = 2*Mjb(i)/L(i);
        Vc2(i) = 2*Mjb(i)/H(i);
        
        % 収束計算の評価
        err_b(i) = abs((Vb2(i)-Vb(i))/Vb(i));
        err_c(i) = abs((Vc2(i)-Vc(i))/Vc(i));
        Vb(i) = Vb2(i);
        Vc(i) = Vc2(i);
        iter(i) = iter(i)+1;
    end
end

return