% 接合部の釣合モーメント：式(9)（楠原・塩原理論2010：鉄筋コンクリート造十字形柱梁接合部の終局モーメント算定法より）
function [gamma_hb,gamma_vb,Mjb,Mjhb,Mjvb,Tbb,Tcb,xi1] = Mjb9_func0(n, ...
    Ab,Ac,bb,bc,beta1,beta3,Db,Dc,eps_u,Esb,Esc,fc,gb,gc,H,L,Nb,Nc,R, ...
    Tby,Tcy,Th,Tm,Vb,Vc)
% 条件式で T_zyoken(i) = -eps_u/eps_y(i)*Ty(i) を使う場合は，eps_byとeps_cyを関数の中に入れる

% 変数の配列サイズと初期値の決定
iter = ones(n,1);
err_b = ones(n,1);
err_c = ones(n,1);

Tb2 = zeros(n,1);
Tb2max = zeros(n,1);
Tb_zyoken = zeros(n,1);
Tbb = zeros(n,1);
Tc2 = zeros(n,1);
Tc2max = zeros(n,1);
Tc_zyoken = zeros(n,1);
Tcb = zeros(n,1);

Tb2_index = zeros(n,1);
Tc2_index = zeros(n,1);

C1x = zeros(n,1);
C1y = zeros(n,1);

xi1 = zeros(n,1);
xi2x = zeros(n,1);
xi2y = zeros(n,1);
a = zeros(n,1);
b = zeros(n,1);
c = zeros(n,1);

Mjhb = zeros(n,1);
gamma_hb = zeros(n,1);
Mjvb = zeros(n,1);
gamma_vb = zeros(n,1);
Mjb = zeros(n,1);
Vb2 = zeros(n,1);
Vc2 = zeros(n,1);

% 接合部の釣合モーメント
for i = 1:n
    err_b(i) = 1;
    err_c(i) = 1;
    while err_b(i) >= 1e-8 && err_c(i) >= 1e-8 && iter(i) <= 30
        % 終局時の鉄筋の応力：梁
        Tb2max(i) = 1/2*(1-gb(i))*bb(i)*Db(i)*beta3*fc(i)-(Nb(i)+Th(i))/2-Vc(i)/2;  % 式(7a)
        Tb_zyoken(i) = -Esb(i)*eps_u*Ab(i);  % 式(8a)
        % Tb_zyoken(i) = -eps_u/eps_by(i)*Tby(i);  % 式(8a)
        if abs(Tb2max(i)) <= abs(Tby(i))
            if Tb2max(i) >= Tb_zyoken(i)
                Tb2(i) = Tb2max(i);
                Tb2_index(i) = 1;
            else
                Tb2(i) = Tb_zyoken(i);
                Tb2_index(i) = 4;
            end
        else
            if Tb2max(i) > Tby(i)
                Tb2(i) = Tby(i);
                Tb2_index(i) = 2;
            else
                if Tby(i) <= -Tb_zyoken(i)
                    Tb2(i) = -Tby(i);
                    Tb2_index(i) = 3;
                else
                    Tb2(i) = Tb_zyoken(i);
                    Tb2_index(i) = 4;
                end
            end
        end
        
        % 終局時の鉄筋の応力：柱
        Tc2max(i) = 1/2*(1-gc(i))*bb(i)*Dc(i)*beta3*fc(i)-(Nc(i)+Tm(i))/2-Vb(i)/2;  % 式(7b)
        Tc_zyoken(i) = -Esc(i)*eps_u*Ac(i);  % 式(8b)
        % Tc_zyoken(i) = -eps_u/eps_cy(i)*Tcy(i);  % 式(8b)
        if abs(Tc2max(i)) <= abs(Tcy(i))
            if Tc2max(i) >= Tc_zyoken(i)
                Tc2(i) = Tc2max(i);
                Tc2_index(i) = 1;
            else
                Tc2(i) = Tc_zyoken(i);
                Tc2_index(i) = 4;
            end
        else
            if Tc2max(i) > Tcy(i)
                Tc2(i) = Tcy(i);
                Tc2_index(i) = 2;
            else
                if Tcy(i) <= -Tc_zyoken(i)
                    Tc2(i) = -Tcy(i);
                    Tc2_index(i) = 3;
                else
                    Tc2(i) = Tc_zyoken(i);
                    Tc2_index(i) = 4;
                end
            end
        end
        
        % 釣り合い破壊時の鉄筋の応力と中立軸位置
        xi2x(i) = 1/beta1(i)*(Tb2(i)+(Nb(i)+Th(i))/2+Vc(i)/2)/(bb(i)*Db(i)*beta3*fc(i));  % 式(20a)
        xi2y(i) = 1/beta1(i)*(Tc2(i)+(Nc(i)+Tm(i))/2+Vb(i)/2)/(bb(i)*Dc(i)*beta3*fc(i));  % 式(20b)
        
        a(i) = 1/(2*(1+R(i)^2)^2*Esb(i)*Ab(i))*gb(i)*bc(i)*Db(i)*beta1(i)*beta3*fc(i) ...
            +1/(2*(1+1/R(i)^2)^2*Esc(i)*Ac(i))*gc(i)*bc(i)*Dc(i)*beta1(i)*beta3*fc(i);
        b(i) = 1/(2*(1+R(i)^2)*Esb(i)*Ab(i))*gb(i)*(-(Nb(i)+Th(i))/2+Vc(i)/2+Tb2(i)) ...
            +1/(2*(1+1/R(i)^2)*Esc(i)*Ac(i))*gc(i)*(-(Nc(i)+Tm(i))/2+Vb(i)/2+Tc2(i))+eps_u;
        c(i) = eps_u*(xi2x(i)+xi2y(i)-1);  % 式(21)及び，岡野先生誘導メモ：付録2
        
        xi1(i) = (-b(i)+sqrt(b(i)^2-4*a(i)*c(i)))/(2*a(i));  % 2次方程式の解の公式
        
        C1x(i) = 1/(1+R(i)^2)*xi1(i)*bc(i)*Db(i)*beta1(i)*beta3*fc(i);    % 式(19a)
        C1y(i) = 1/(1+1/R(i)^2)*xi1(i)*bc(i)*Dc(i)*beta1(i)*beta3*fc(i);  % 式(19b)
        
        % 接合部の限界補強量
        Tbb(i) = C1x(i)-(Nb(i)+Th(i))/2+Vc(i)/2;  % 式(1a)：この式に，式(19a)を代入すると，式(22a)になる
        Tcb(i) = C1y(i)-(Nc(i)+Tm(i))/2+Vb(i)/2;  % 式(1b)：この式に，式(19b)を代入すると，式(22b)になる
        
        % 接合部の釣合モーメント
        if Tb2(i) == Tb2max(i)  % 圧縮主筋の応力が抵抗モーメント極大時の応力の場合
            Mjhb(i) = 1/(1+R(i)^2)*(gb(i)-1/(1+R(i)^2)*beta1(i)*xi1(i)) ...
                *beta1(i)*xi1(i)*bc(i)*Db(i)^2*beta3*fc(i) ...
                +1/4*(1-gb(i))^2*bb(i)*Db(i)^2*beta3*fc(i);  % 式(23a)
            gamma_hb(i) = 2*gb(i);  % 式(23b)
        else                    % 圧縮主筋が圧縮ひずみの制限による場合
            Mjhb(i) = 1/(1+R(i)^2)*(gb(i)-1/(1+R(i)^2)*beta1(i)*xi1(i)) ...
                *beta1(i)*xi1(i)*bc(i)*Db(i)^2*beta3*fc(i) ...
                +((1-gb(i))-(Tb2(i)+(Nb(i)+Th(i))/2)/(bb(i)*Db(i)*beta3*fc(i))) ...
                *(Tb2(i)+(Nb(i)+Th(i))/2)*Db(i);  % 式(25a)
            gamma_hb(i) = 1+gb(i)-2*bc(i)/bb(i)*(Tb2(i)+(Nb(i)+Th(i))/2) ...
                /(bc(i)*Db(i)*beta3*fc(i)) ...
                -bc(i)/bb(i)*(Vc(i)/2)/(bc(i)*Db(i)*beta3*fc(i));  % 式(25b)
        end
        
        if Tc2(i) == Tc2max(i)  % 圧縮主筋の応力が抵抗モーメント極大時の応力の場合
            Mjvb(i) = 1/(1+1/R(i)^2)*(gc(i)-1/(1+1/R(i)^2) ...
                *beta1(i)*xi1(i))*beta1(i)*xi1(i)*bc(i)*Dc(i)^2*beta3*fc(i) ...
                +1/4*(1-gc(i))^2*bb(i)*Dc(i)^2*beta3*fc(i);  % 式(24a)
            gamma_vb(i) = 2*gc(i); % 式(24b)
        else                    % 圧縮主筋が圧縮ひずみの制限による場合
            Mjvb(i) = 1/(1+1/R(i)^2)*(gc(i)-1/(1+1/R(i)^2)*beta1(i)*xi1(i)) ...
                *beta1(i)*xi1(i)*bc(i)*Dc(i)^2*beta3*fc(i) ...
                +((1-gc(i))-(Tc2(i)+(Nc(i)+Tm(i))/2)/(bb(i)*Dc(i)*beta3*fc(i))) ...
                *(Tc2(i)+(Nc(i)+Tm(i))/2)*Dc(i);  % 式(26a)
            gamma_vb(i) = 1+gc(i)-2*bc(i)/bb(i)*(Tc2(i)+(Nc(i)+Tm(i))/2) ...
                /(bc(i)*Dc(i)*beta3*fc(i)) ...
                -bc(i)/bb(i)*(Vb(i)/2)/(bc(i)*Dc(i)*beta3*fc(i));  % 式(26b)
        end
        
        % Mjb(i) = 1/2*(Mjhb(i)+Mjvb(i)) ...
        %     +1/2*(gamma_hb(i)*Db(i)*Vc(i)/2+gamma_vb(i)*Dc(i)*Vb(i)/2);  % 式(9)
        Mjb(i) = (1/2*(Mjhb(i)+Mjvb(i))) ...
            /(1-1/2*(gamma_hb(i)*Db(i)/H(i)+gamma_vb(i)*Dc(i)/L(i)));  % 式(10)
        
        % 柱，梁せん断力と接合部の抵抗モーメントの関係
        Vb2(i) = 0;
        Vc2(i) = 0;
        
        % 収束計算の評価
        err_b(i) = abs((Vb2(i)-Vb(i))/Vb(i));
        err_c(i) = abs((Vc2(i)-Vc(i))/Vc(i));
        Vb(i) = 0;
        Vc(i) = 0;
        iter(i) = iter(i)+1;
    end
end

return