% 接合部の終局モーメント：式(6)（楠原・塩原理論2010：鉄筋コンクリート造十字形柱梁接合部の終局モーメント算定法より）
function [Mju,Tb1_index,Tb2_index,Tc1_index,Tc2_index] = Mju6_func2(n, ...
    Ab,Ac,bb,bc,beta3,Db,Dc,eps_u,Esb,Esc,fc,gb,gc,H,L,Nb,Nc, ...
    Tbb,Tby,Tcb,Tcy,Thc,Thy,Tmc,Tmy,Vb,Vc)
% 条件式で T_zyoken(i) = -eps_u/eps_y(i)*Ty(i) を使う場合は，eps_byとeps_cyを関数の中に入れる

% 変数の配列サイズと初期値の決定
iter = ones(n,1);
err_b = ones(n,1);
err_c = ones(n,1);

Tb1 = zeros(n,1);
Tb2 = zeros(n,1);
Tb2max = zeros(n,1);
Tb_zyoken = zeros(n,1);
Tc1 = zeros(n,1);
Tc2 = zeros(n,1);
Tc2max = zeros(n,1);
Tc_zyoken = zeros(n,1);

Tb1_index = zeros(n,1);
Tb2_index = zeros(n,1);
Tc1_index = zeros(n,1);
Tc2_index = zeros(n,1);

Th = zeros(n,1);
Tm = zeros(n,1);

C1x = zeros(n,1);  % 接合部中央のコンクリート応力の水平成分[N]
C1y = zeros(n,1);  % 接合部中央のコンクリート応力の鉛直成分[N]
C2x = zeros(n,1);  % 接合部入隅部のコンクリート応力の水平成分[N]
C2y = zeros(n,1);  % 接合部入隅部のコンクリート応力の鉛直成分[N]
j1x = zeros(n,1);  % 柱，梁の上段筋から接合部中央のコンクリート応力の作用位置までの距離[mm]
j1y = zeros(n,1);  % 柱，梁の上段筋から接合部中央のコンクリート応力の作用位置までの距離[mm]
j2x = zeros(n,1);  % 柱，梁の下段筋から接合部入隅部のコンクリート応力の作用位置までの距離[mm]
j2y = zeros(n,1);  % 柱，梁の下段筋から接合部入隅部のコンクリート応力の作用位置までの距離[mm]

Mju = zeros(n,1);   % 接合部の抵抗モーメント[N・mm]
dMj1 = zeros(n,1);  % 接合部の抵抗モーメントの軸力による増分[N・mm]
dMj2 = zeros(n,1);  % 接合部の抵抗モーメントのせん断力による増分[N・mm]
Vb2 = zeros(n,1);
Vc2 = zeros(n,1);

% 接合部の終局モーメント
for i = 1:n
    err_b(i) = 1;
    err_c(i) = 1;
    while err_b(i) >= 1e-8 && err_c(i) >= 1e-8 && iter(i) <= 30
        % 終局時の鉄筋の応力：梁
        if Tby(i) >= Tbb(i)
            Tb1(i) = Tbb(i);
            Th(i) = Thc(i);
            Tb1_index(i) = 1;
        else
            Tb1(i) = Tby(i);
            Th(i) = Thy(i);
        end
        
        Tb2max(i) = 1/2*(1-gb(i))*bb(i)*Db(i)*beta3*fc(i)-(Nb(i)+Th(i))/2-Vc(i)/2;  % 式(7a)
        Tb_zyoken(i) = -Esb(i)*eps_u*Ab(i);  % 式(8a)
        % Tb_zyoken(i) = -eps_u/eps_by(i)*Tby(i);  % 式(8a)
        if abs(Tb2max(i)) <= abs(Tby(i))
            if Tb2max(i) >= Tb_zyoken(i)
                Tb2(i) = Tb2max(i);
                Tb2_index(i) = 1;
            else
                Tb2(i) = Tb_zyoken(i);
                Tb2_index(i) = 4;
            end
        else
            if Tb2max(i) > Tby(i)
                Tb2(i) = Tby(i);
                Tb2_index(i) = 2;
            else
                if Tby(i) <= -Tb_zyoken(i)
                    Tb2(i) = -Tby(i);
                    Tb2_index(i) = 3;
                else
                    Tb2(i) = Tb_zyoken(i);
                    Tb2_index(i) = 4;
                end
            end
        end
        
        % 終局時の鉄筋の応力：柱
        if Tcy(i) >= Tcb(i)
            Tc1(i) = Tcb(i);
            Tm(i) = Tmc(i);
            Tc1_index(i) = 1;
        else
            Tc1(i) = Tcy(i);
            Tm(i) = Tmy(i);
        end
        
        Tc2max(i) = 1/2*(1-gc(i))*bb(i)*Dc(i)*beta3*fc(i)-(Nc(i)+Tm(i))/2-Vb(i)/2;  % 式(7b)
        Tc_zyoken(i) = -Esc(i)*eps_u*Ac(i);  % 式(8b)
        % Tc_zyoken(i) = -eps_u/eps_cy(i)*Tcy(i);  % 式(8b)
        if abs(Tc2max(i)) <= abs(Tcy(i))
            if Tc2max(i) >= Tc_zyoken(i)
                Tc2(i) = Tc2max(i);
                Tc2_index(i) = 1;
            else
                Tc2(i) = Tc_zyoken(i);
                Tc2_index(i) = 4;
            end
        else
            if Tc2max(i) > Tcy(i)
                Tc2(i) = Tcy(i);
                Tc2_index(i) = 2;
            else
                if Tcy(i) <= -Tc_zyoken(i)
                    Tc2(i) = -Tcy(i);
                    Tc2_index(i) = 3;
                else
                    Tc2(i) = Tc_zyoken(i);
                    Tc2_index(i) = 4;
                end
            end
        end
        
        % コンクリート応力の大きさ
        C1x(i) = Tb1(i)+(Nb(i)+Th(i))/2-Vc(i)/2;  % 式(1a)
        C1y(i) = Tc1(i)+(Nc(i)+Tm(i))/2-Vb(i)/2;  % 式(1b)
        C2x(i) = Tb2(i)+(Nb(i)+Th(i))/2+Vc(i)/2;  % 式(1c)
        C2y(i) = Tc2(i)+(Nc(i)+Tm(i))/2+Vb(i)/2;  % 式(1d)
        
        % コンクリート応力の作用位置
        j1x(i) = gb(i)*Db(i)/2-1/2*C1x(i)/(bc(i)*beta3*fc(i));      % 式(2a)
        j1y(i) = gc(i)*Dc(i)/2-1/2*C1y(i)/(bc(i)*beta3*fc(i));      % 式(2b)
        j2x(i) = (1-gb(i))*Db(i)/2-1/2*C2x(i)/(bb(i)*beta3*fc(i));  % 式(2c)
        j2y(i) = (1-gc(i))*Dc(i)/2-1/2*C2y(i)/(bb(i)*beta3*fc(i));  % 式(2d)
        
        % 接合部の抵抗モーメント
        Mju(i) = Tb1(i)*j1x(i)+Tb2(i)*j2x(i)+Tc1(i)*j1y(i)+Tc2(i)*j2y(i);                                   % 式(3)
        dMj1(i) = (Nb(i)+Th(i))/2*(j1x(i)+j2x(i))+(Nc(i)+Tm(i))/2*(j1y(i)+j2y(i));                          % 式(4)
        dMj2(i) = Vc(i)/2*gb(i)*Db(i)+Vb(i)/2*gc(i)*Dc(i)-Vc(i)/2*(j1x(i)-j2x(i))-Vb(i)/2*(j1y(i)-j2y(i));  % 式(5)
        Mju(i) = Mju(i)+dMj1(i)+dMj2(i);                                                                    % 式(6)
        
        % 柱，梁せん断力と接合部の抵抗モーメントの関係
        Vb2(i) = 2*Mju(i)/L(i);
        Vc2(i) = 2*Mju(i)/H(i);
        
        % 収束計算の評価
        err_b(i) = abs((Vb2(i)-Vb(i))/Vb(i));
        err_c(i) = abs((Vc2(i)-Vc(i))/Vc(i));
        Vb(i) = Vb2(i);
        Vc(i) = Vc2(i);
        iter(i) = iter(i)+1;
    end
end

return