% 接合部の終局モーメント
% 建築研究資料「実験データベースを用いた鉄筋コンクリート造部材の構造特性評価式の検証（2020年版）」より
function [gamma_h,gamma_v,Mjh,Mjv,Mju,Tb1_index,Tc1_index, ...
    Tb2_index,Tc2_index] = Mju9_func2020(n,Ab,Ac,bb,bc,beta3, ...
    Db,Dc,eps_u,Esb,Esc,fc,gb,gc,H,L,Nc,Tbb,Tby,Tcb,Tcy,Thy,Tmy)

% 変数の配列サイズと初期値の決定
Tb1 = zeros(n,1);
Tb2 = zeros(n,1);
Tb2max = zeros(n,1);
Tb_zyoken = zeros(n,1);
Tc1 = zeros(n,1);
Tc2 = zeros(n,1);
Tc2max = zeros(n,1);
Tc_zyoken = zeros(n,1);

Tb1_index = zeros(n,1);
Tb2_index = zeros(n,1);
Tc1_index = zeros(n,1);
Tc2_index = zeros(n,1);

Mjh = zeros(n,1);
gamma_h = zeros(n,1);
alpha_b = zeros(n,1);
Mjv = zeros(n,1);
gamma_v = zeros(n,1);
alpha_c = zeros(n,1);
Mju = zeros(n,1);

% 接合部の終局モーメント
for i = 1:n
    Tb1(i) = min(Tby(i),Tbb(i));
    if Tb1(i) == Tbb(i)
        Tb1_index(i) = 1;
    end
    
    Tc1(i) = min(Tcy(i),Tcb(i));
    if Tc1(i) == Tcb(i)
        Tc1_index(i) = 1;
    end
    
    % 接合部の終局モーメント
    Mjh(i) = (gb(i)-(Tb1(i)+Thy(i)/2)/(bc(i)*Db(i)*beta3*fc(i))) ...
        *(Tb1(i)+Thy(i)/2)*Db(i) ...
        +1/4*(1-gb(i))^2*bb(i)*Db(i)^2*beta3*fc(i);  % 式(8.40)
    gamma_h(i) = gb(i)+2*(Tb1(i)+Thy(i)/2)/(bc(i)*Db(i)*beta3*fc(i));  % 式(8.41)
    
    Mjv(i) = (gc(i)-(Tc1(i)+(Nc(i)+Tmy(i))/2)/(bc(i)*Dc(i)*beta3*fc(i))) ...
        *(Tc1(i)+(Nc(i)+Tmy(i))/2)*Dc(i) ...
        +1/4*(1-gc(i))^2*bb(i)*Dc(i)^2*beta3*fc(i);  % 式(8.42)
    gamma_v(i) = gc(i)+2*(Tc1(i)+(Nc(i)+Tmy(i))/2) ...
        /(bc(i)*Dc(i)*beta3*fc(i));  % 式(8.43)
    
    Mju(i) = (1/2*(Mjh(i)+Mjv(i))) ...
        /(1-1/2*(gamma_h(i)*Db(i)/H(i)+gamma_v(i)*Dc(i)/L(i)));  % 式(8.39)
    
    Tb_zyoken(i) = -Esb(i)*eps_u*Ab(i);  % 式(8.44)
    Tb2max(i) = 1/2*(1-gb(i))*bb(i)*Db(i)*beta3*fc(i)-Thy(i)/2-Mju(i)/H(i);  % 式(8.45)
    if abs(Tb2max(i)) <= abs(Tby(i))
        if Tb2max(i) >= Tb_zyoken(i)
            Tb2(i) = Tb2max(i);
            Tb2_index(i) = 1;
        else
            Tb2(i) = Tb_zyoken(i);
            Tb2_index(i) = 4;
        end
    else
        if Tb2max(i) > Tby(i)
            Tb2(i) = Tby(i);
            Tb2_index(i) = 2;
        else
            if Tby(i) <= -Tb_zyoken(i)
                Tb2(i) = -Tby(i);
                Tb2_index(i) = 3;
            else
                Tb2(i) = Tb_zyoken(i);
                Tb2_index(i) = 4;
            end
        end
    end
    if Tb2_index(i) ~= 1
        alpha_b(i) = Tb2(i)/Tb1(i);
        Mjh(i) = (1-(1+bc(i)/bb(i))*(Tb1(i)+Thy(i)/2) ...
            /(bc(i)*Db(i)*beta3*fc(i)))*(Tb1(i)+Thy(i)/2)*Db(i) ...
            -(1-alpha_b(i))*((1-gb(i))-bc(i)/bb(i) ...
            *((1+alpha_b(i))*Tb1(i)+Thy(i)) ...
            /(bc(i)*Db(i)*beta3*fc(i)))*Tb1(i)*Db(i);  % 式(8.46)
        gamma_h(i) = 1+2*((1-bc(i)/bb(i))*(Tb1(i)+Thy(i)/2) ...
            /(bc(i)*Db(i)*beta3*fc(i))+(1-alpha_b(i))*bc(i)/bb(i)*Tb1(i) ...
            /(bc(i)*Db(i)*beta3*fc(i)));  % 式(8.47)
        Mju(i) = (1/2*(Mjh(i)+Mjv(i))) ...
            /(1-1/2*(gamma_h(i)*Db(i)/H(i)+gamma_v(i)*Dc(i)/L(i)));  % 式(8.39)
    end
    
    Tc_zyoken(i) = -Esc(i)*eps_u*Ac(i);  % 式(8.48)
    Tc2max(i) = 1/2*(1-gc(i))*bb(i)*Dc(i)*beta3*fc(i)-(Nc(i)+Tmy(i))/2-Mju(i)/L(i);  % 式(8.49)
    if abs(Tc2max(i)) <= abs(Tcy(i))
        if Tc2max(i) >= Tc_zyoken(i)
            Tc2(i) = Tc2max(i);
            Tc2_index(i) = 1;
        else
            Tc2(i) = Tc_zyoken(i);
            Tc2_index(i) = 4;
        end
    else
        if Tc2max(i) > Tcy(i)
            Tc2(i) = Tcy(i);
            Tc2_index(i) = 2;
        else
            if Tcy(i) <= -Tc_zyoken(i)
                Tc2(i) = -Tcy(i);
                Tc2_index(i) = 3;
            else
                Tc2(i) = Tc_zyoken(i);
                Tc2_index(i) = 4;
            end
        end
    end
    if Tc2_index(i) ~= 1
        alpha_c(i) = Tc2(i)/Tc1(i);
        Mjv(i) = (1-(1+bc(i)/bb(i))*(Tc1(i)+(Nc(i)+Tmy(i))/2) ...
            /(bc(i)*Dc(i)*beta3*fc(i)))*(Tc1(i)+(Nc(i)+Tmy(i))/2)*Dc(i) ...
            -(1-alpha_c(i))*((1-gc(i))-bc(i)/bb(i) ...
            *((1+alpha_c(i))*Tc1(i)+(Nc(i)+Tmy(i))) ...
            /(bc(i)*Dc(i)*beta3*fc(i)))*Tc1(i)*Dc(i);  % 式(8.50)
        gamma_v(i) = 1+2*((1-bc(i)/bb(i))*(Tc1(i)+(Nc(i)+Tmy(i))/2) ...
            /(bc(i)*Dc(i)*beta3*fc(i))+(1-alpha_c(i))*bc(i)/bb(i)*Tc1(i) ...
            /(bc(i)*Dc(i)*beta3*fc(i)));  % 式(8.51)
        Mju(i) = (1/2*(Mjh(i)+Mjv(i))) ...
            /(1-1/2*(gamma_h(i)*Db(i)/H(i)+gamma_v(i)*Dc(i)/L(i)));  % 式(8.39)
    end
end

return