% 柱の曲げ終局強度
function [Nmax_c,Nmin_c,Nb_c,Mu_c,Mc_index] = Mu_c4(opt,n,b_c,Dc,fc_c,g1,at_c,ag_c,sigma_cy,n_top2c,n_btm2c,n_m,Nc)

% 柱軸方向の終局強度
Nmax_c = b_c.*Dc.*fc_c+ag_c.*sigma_cy;  % 柱軸方向の圧縮終局強度[N]（2015年版黄色本：p.655 or 659，式(付1.3-19)）
Nmin_c = -sigma_cy.*ag_c;                 % 柱軸方向の引張終局強度[N]（2015年版黄色本：p.655 or 659，式(付1.3-18)）
Nb_c = 0.22*(1+g1).*b_c.*Dc.*fc_c;        % 柱の主筋間距離比を用いて表した軸方向力[N]（2015年版黄色本：p.656）

% 柱の曲げ終局強度
Mu_c = zeros(n,1); % 柱の曲げ終局強度[N・mm]（2015年版黄色本：pp.655-656）
Mc_index = zeros(n,1);

% エラーの確認
cnt = 1;

for i = 1:n  % 長方形断面柱で，上下に各1段配筋の場合
    if n_top2c(i) == 0 && n_btm2c(i) == 0 && n_m(i) == 0 && opt == 1
        if Nc(i) < Nmin_c(i)
            Mu_c = 0;
            Mc_index(i) = 1;
        elseif Nc(i) < 0
            Mu_c(i) = 0.8*at_c(i)*sigma_cy(i)*Dc(i)+0.4*Nc(i)*Dc(i);       % 式(付1.3-10)
            Mc_index(i) = 2;
        elseif Nc(i) <= 0.4*b_c(i)*Dc(i)*fc_c(i)
            Mu_c(i) = 0.8*at_c(i)*sigma_cy(i)*Dc(i)+...
                0.5*Nc(i)*Dc(i)*(1-Nc(i)/(b_c(i)*Dc(i)*fc_c(i)));          % 式(付1.3-11)
            Mc_index(i) = 3;
        elseif Nc(i) <= Nmax_c(i)
            Mu_c(i) = (0.8*at_c(i)*sigma_cy(i)*Dc(i)+0.12*b_c(i)*Dc(i)^2*fc_c(i))*...
                ((Nmax_c(i)-Nc(i))/(Nmax_c(i)-0.4*b_c(i)*Dc(i)*fc_c(i)));  % 式(付1.3-12)
            Mc_index(i) = 4;
        else
            disp('*** Nc may be wrong. ***');
            fprintf('i = %d\n',i);
            % return
        end
        
    else  % 長方形断面柱で，多段配筋の場合
        if Nc(i) < Nmin_c(i)
            Mu_c(i) = 0;
            Mc_index(i) = 5;
        elseif Nc(i) < 0
            Mu_c(i) = 0.5*ag_c(i)*sigma_cy(i)*g1(i)*Dc(i)+0.5*Nc(i)*g1(i)*Dc(i);  % 式(付1.3-13)
            Mc_index(i) = 6;
        elseif Nc(i) <= Nb_c(i)
            Mu_c(i) = 0.5*ag_c(i)*sigma_cy(i)*g1(i)*Dc(i)+...
                0.5*Nc(i)*Dc(i)*(1-Nc(i)/(b_c(i)*Dc(i)*fc_c(i)));                 % 式(付1.3-14)
            Mc_index(i) = 7;
        elseif Nc(i) <= Nmax_c(i)
            Mu_c(i) = (0.5*ag_c(i)*sigma_cy(i)*g1(i)*Dc(i)+0.024*(1+g1(i))*(3.6-g1(i))*b_c(i)*Dc(i)^2*fc_c(i))*...
                ((Nmax_c(i)-Nc(i))/(Nmax_c(i)-Nb_c(i)));                          % 式(付1.3-15)
            Mc_index(i) = 8;
        else
            if cnt == 1
                disp('*** Nc may be wrong. ***');
                fprintf('i = %d ',i);
            else
                fprintf('%d ',i);
            end
            cnt = cnt+1;
            % return
        end
    end
end

if cnt ~= 1
    fprintf('\n');
end

return